@@ -3,6 +3,8 @@
 import json
 from pathlib import Path
 from typing import List, Union, Optional, Dict, Any, Literal
+from pydantic import BaseModel
+from copy import deepcopy
 
 import requests
 
@@ -14,6 +16,9 @@ from ..models.assistant import (
     AssistantChatRequest,
     BaseModelResponse,
     AssistantBase,
+    Context,
+    ExportAssistantPayload,
+    AssistantEvaluationRequest,
 )
 from ..models.common import PaginationParams
 from ..utils import ApiRequestHandler
@@ -35,7 +40,7 @@ class AssistantService:
     def list(
         self,
         minimal_response: bool = True,
-        scope: Literal["visible_to_user", "created_by_user"] = "visible_to_user",
+        scope: Literal["visible_to_user", "marketplace"] = "visible_to_user",
         page: int = 0,
         per_page: int = 12,
         filters: Optional[Dict[str, Any]] = None,
@@ -122,6 +127,17 @@ class AssistantService:
             "/v1/assistants/tools", List[ToolKitDetails], wrap_response=False
         )
 
+    def get_context(self, project_name: str) -> List[Context]:
+        """Get list of available contexts.
+
+        Args: project_name: Name of the project to retrieve context for
+
+        Returns:
+            All available assistants context
+        """
+        params = {"project_name": project_name}
+        return self._api.get("/v1/assistants/context", List[Context], params=params)
+
     def delete(self, assistant_id: str) -> dict:
         """Delete an assistant by ID.
 
@@ -166,12 +182,23 @@ class AssistantService:
         Returns:
             Chat response or streaming response
         """
-        return self._api.post(
+        pydantic_schema = None
+        if issubclass(request.output_schema, BaseModel):
+            pydantic_schema = deepcopy(request.output_schema)
+            request.output_schema = request.output_schema.model_json_schema()
+
+        response = self._api.post(
             f"/v1/assistants/{assistant_id}/model",
             BaseModelResponse,
             json_data=request.model_dump(exclude_none=True, by_alias=True),
             stream=request.stream,
         )
+        if not request.stream and pydantic_schema:
+            # we do conversion to the BaseModel here because self._parse_response don't see actual request model,
+            # where reflected desired output format for structured output
+            response.generated = pydantic_schema.model_validate(response.generated)
+
+        return response
 
     def upload_file_to_chat(self, file_path: Path):
         """Upload a file to assistant chat and return the response containing file_url."""
@@ -183,3 +210,36 @@ class AssistantService:
             response = self._api.post_multipart("/v1/files/", dict, files=files)
 
         return response
+
+    def export(self, assistant_id: str, request: ExportAssistantPayload):
+        """Export an assistant.
+
+        Args:
+            assistant_id: ID of the assistant to export
+            request: Export request details
+
+        Returns:
+             input stream of the exported assistant file"""
+
+        return self._api.post(
+            f"/v1/assistants/id/{assistant_id}/export",
+            response_model=Any,
+            stream=True,
+            json_data=request.model_dump(exclude_none=True),
+        )
+
+    def evaluate(self, assistant_id: str, request: AssistantEvaluationRequest) -> dict:
+        """Evaluate an assistant with a dataset.
+
+        Args:
+            assistant_id: ID of the assistant to evaluate
+            request: Evaluation request details
+
+        Returns:
+            Evaluation results
+        """
+        return self._api.post(
+            f"/v1/assistants/{assistant_id}/evaluate",
+            dict,
+            json_data=request.model_dump(exclude_none=True),
+        )
